componenttools.iterate_thread_backward_in_expr
==============================================

.. autofunction:: abjad.tools.componenttools.iterate_thread_backward_in_expr.iterate_thread_backward_in_expr
